@@ -6,8 +6,10 @@
 """
 
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
  
 from mon_test.mon_test_script import mon_script_methode
 from mon_test.mon_test_script import favorite_meal
-from mon_test.mon_test_script import voiture_de_reve
\ No newline at end of file
+from mon_test.mon_test_script import voiture_de_reve
+from mon_test.mon_test_script import list_de_toutou
+from mon_test.mon_test_script import associe
\ No newline at end of file
